==> myfaces-core-assembly-2.3.10-src.zip: myfaces-core-module-2.3.10/impl/src/test/java/org/apache/myfaces/view/facelets/pss/acid/managed/ForEachBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.pss.acid.managed;

import java.util.ArrayList;
import java.util.List;
import javax.annotation.PostConstruct;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

/**
 *
 */
@ManagedBean(name="forEachBean")
@SessionScoped
public class ForEachBean
{
    private List<String> items1;
    
    public ForEachBean()
    {
        items1 = new ArrayList<String>();
        items1.add("a");
        items1.add("b");
        items1.add("c");
    }

    /**
     * @return the items1
     */
    public List<String> getItems1()
    {
        return items1;
    }
    
    public void addFirst()
    {
        items1.add(0, "z");
    }

    public void addMiddle()
    {
        items1.add(2, "x");
    }

    public void removeLast()
    {
        items1.remove(items1.size()-1);
    }
}

==> myfaces-core-assembly-3.0.3-src.zip: myfaces-core-module-3.0.3/impl/src/test/java/org/apache/myfaces/view/facelets/pss/acid/managed/ForEachBean.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.myfaces.view.facelets.pss.acid.managed;

import java.util.ArrayList;
import java.util.List;

import jakarta.faces.bean.ManagedBean;
import jakarta.faces.bean.SessionScoped;

/**
 *
 */
@ManagedBean(name="forEachBean")
@SessionScoped
public class ForEachBean
{
    private List<String> items1;
    
    public ForEachBean()
    {
        items1 = new ArrayList<String>();
        items1.add("a");
        items1.add("b");
        items1.add("c");
    }

    /**
     * @return the items1
     */
    public List<String> getItems1()
    {
        return items1;
    }
    
    public void addFirst()
    {
        items1.add(0, "z");
    }

    public void addMiddle()
    {
        items1.add(2, "x");
    }

    public void removeLast()
    {
        items1.remove(items1.size()-1);
    }
}
